@@ -133,8 +133,16 @@ public:
      * by calling setDefaultToolBar( const QString& ) on the dialog.
      *
      * @param  toolBarName  the name of the tool bar
+     * @since 6.0
      */
-    static void setGlobalDefaultToolBar(const char *toolBarName); // TODO should be const QString&
+    static void setGlobalDefaultToolBar(const QString &toolBarName);
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 240)
+    KXMLGUI_DEPRECATED_VERSION(5, 240, "Use setGlobalDefaultToolBar(const QString &) overload")
+    static void setGlobalDefaultToolBar(const char *toolBarName)
+    {
+        setGlobalDefaultToolBar(QString::fromLatin1(toolBarName));
+    }
+#endif
 
 Q_SIGNALS:
     /**
@@ -144,14 +152,6 @@ Q_SIGNALS:
      */
     void newToolBarConfig();
 
-#if KXMLGUI_ENABLE_DEPRECATED_SINCE(4, 0)
-    /**
-     * @deprecated Since 4.0, use newToolBarConfig()
-     */
-    KXMLGUI_DEPRECATED_VERSION(4, 0, "Use KEditToolBar::newToolBarConfig()")
-    QT_MOC_COMPAT void newToolbarConfig();
-#endif
-
 protected:
     void showEvent(QShowEvent *event) override;
     void hideEvent(QHideEvent *event) override;
@@ -160,10 +160,6 @@ private:
     friend class KEditToolBarPrivate;
     std::unique_ptr<KEditToolBarPrivate> const d;
 
-    Q_PRIVATE_SLOT(d, void _k_slotButtonClicked(QAbstractButton *))
-    Q_PRIVATE_SLOT(d, void _k_acceptOK(bool))
-    Q_PRIVATE_SLOT(d, void _k_enableApply(bool))
-
     Q_DISABLE_COPY(KEditToolBar)
 };
 
