@@ -27,9 +27,6 @@
 #include <QTextStream>
 #include <QVariant>
 #include <QWidget>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTextCodec>
-#endif
 
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -37,8 +34,6 @@
 #include <KGlobalAccel>
 #endif
 
-Q_DECLARE_METATYPE(QList<QKeySequence>)
-
 using namespace KXMLGUI;
 
 class KXMLGUIFactoryPrivate : public BuildState
@@ -106,32 +101,12 @@ QString KXMLGUIFactory::readConfigFile(const QString &filename, const QString &_
     if (!QDir::isRelativePath(filename)) {
         xml_file = filename;
     } else {
-        // KF >= 5.1 (KDE_INSTALL_KXMLGUI5DIR)
+        // first look for any custom user config, admin config or the default deployed as file
         xml_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kxmlgui5/") + componentName + QLatin1Char('/') + filename);
         if (!QFile::exists(xml_file)) {
-            // KF >= 5.4 (resource file)
+            // fall-back to any built-in resource file
             xml_file = QLatin1String(":/kxmlgui5/") + componentName + QLatin1Char('/') + filename;
         }
-
-        bool warn = false;
-        if (!QFile::exists(xml_file)) {
-            // kdelibs4 / KF 5.0 solution
-            xml_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, componentName + QLatin1Char('/') + filename);
-            warn = true;
-        }
-
-        if (!QFile::exists(xml_file)) {
-            // kdelibs4 / KF 5.0 solution, and the caller includes the component name
-            // This was broken (lead to component/component/ in kdehome) and unnecessary
-            // (they can specify it with setComponentName instead)
-            xml_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, filename);
-            warn = true;
-        }
-
-        if (warn && !xml_file.isEmpty()) {
-            qCWarning(DEBUG_KXMLGUI) << "KXMLGUI file found at deprecated location" << xml_file
-                                     << "-- please use ${KDE_INSTALL_KXMLGUI5DIR} to install these files instead.";
-        }
     }
 
     QFile file(xml_file);
@@ -163,10 +138,6 @@ bool KXMLGUIFactory::saveConfigFile(const QDomDocument &doc, const QString &file
 
     // write out our document
     QTextStream ts(&file);
-    // The default in Qt6 is UTF-8
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    ts.setCodec(QTextCodec::codecForName("UTF-8"));
-#endif
     ts << doc;
 
     file.close();
@@ -314,7 +285,7 @@ void KXMLGUIFactory::refreshActionProperties()
 
 static QString currentShortcutScheme()
 {
-    const KConfigGroup cg = KSharedConfig::openConfig()->group("Shortcut Schemes");
+    const KConfigGroup cg = KSharedConfig::openConfig()->group(QStringLiteral("Shortcut Schemes"));
     return cg.readEntry("Current Scheme", "Default");
 }
 
@@ -394,7 +365,7 @@ void KXMLGUIFactoryPrivate::saveDefaultActionProperties(const QList<QAction *> &
 void KXMLGUIFactory::changeShortcutScheme(const QString &scheme)
 {
     qCDebug(DEBUG_KXMLGUI) << "Changing shortcut scheme to" << scheme;
-    KConfigGroup cg = KSharedConfig::openConfig()->group("Shortcut Schemes");
+    KConfigGroup cg = KSharedConfig::openConfig()->group(QStringLiteral("Shortcut Schemes"));
     cg.writeEntry("Current Scheme", scheme);
 
     refreshActionProperties();
@@ -632,12 +603,12 @@ void KXMLGUIFactoryPrivate::configureAction(QAction *action, const QDomAttr &att
 
     QVariant propertyValue;
 
-    QVariant::Type propertyType = action->property(attrName.toLatin1().constData()).type();
-    bool isShortcut = (propertyType == QVariant::KeySequence);
+    const int propertyType = action->property(attrName.toLatin1().constData()).typeId();
+    bool isShortcut = (propertyType == QMetaType::QKeySequence);
 
-    if (propertyType == QVariant::Int) {
+    if (propertyType == QMetaType::Int) {
         propertyValue = QVariant(attribute.value().toInt());
-    } else if (propertyType == QVariant::UInt) {
+    } else if (propertyType == QMetaType::UInt) {
         propertyValue = QVariant(attribute.value().toUInt());
     } else if (isShortcut) {
         // Setting the shortcut by property also sets the default shortcut (which is incorrect), so we have to do it directly
@@ -708,23 +679,6 @@ void KXMLGUIFactoryPrivate::applyShortcutScheme(const QString &schemeName, KXMLG
     }
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 84)
-int KXMLGUIFactory::configureShortcuts(bool letterCutsOk, bool bSaveSettings)
-{
-    auto *dlg = new KShortcutsDialog(KShortcutsEditor::AllActions,
-                                     letterCutsOk ? KShortcutsEditor::LetterShortcutsAllowed : KShortcutsEditor::LetterShortcutsDisallowed,
-                                     qobject_cast<QWidget *>(parent()));
-    for (KXMLGUIClient *client : std::as_const(d->m_clients)) {
-        if (client) {
-            qCDebug(DEBUG_KXMLGUI) << "Adding collection from client" << client->componentName() << "with" << client->actionCollection()->count() << "actions";
-            dlg->addCollection(client->actionCollection(), client->componentName());
-        }
-    }
-    connect(dlg, &KShortcutsDialog::saved, this, &KXMLGUIFactory::shortcutsSaved);
-    return dlg->configure(bSaveSettings);
-}
-#endif
-
 void KXMLGUIFactory::showConfigureShortcutsDialog()
 {
     auto *dlg = new KShortcutsDialog(qobject_cast<QWidget *>(parent()));
